==> nextcloud-app-contacts-2.1.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/nl.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contactpersonen",
    "Download" : "Downloaden",
    "Copy link" : "Link kopiëren",
    "Click to copy the link to your clipboard" : "Klik om de link naar je klembord te kopiëren",
    "Toggle sharing" : "Gedeelde omschakelen",
    "Delete" : "Verwijderen",
    "Rename" : "Hernoemen",
    "Share with users or groups" : "Delen met gebruikers of groepen",
    "can edit" : "kan bewerken",
    "Close" : "Sluiten",
    "Enabled" : "Ingeschakeld",
    "Disabled" : "Uitgeschakeld",
    "Copied!" : "Gekopieerd!",
    "Not supported!" : "Niet ondersteund!",
    "Press ⌘-C to copy." : "Druk op ⌘-C om te kopiëren.",
    "Press Ctrl-C to copy." : "Druk op Ctrl-C om te kopiëren.",
    "Address book name" : "Adresboek naam",
    "Only these special characters are allowed: -_.!?#|()" : "Alleen de volgende speciale tekens zijn toegestaan: - _ . ! ? # | ( )",
    "Address book could not be created." : "Adresboek kon niet gemaakt worden",
    "The selected image is too big (max 1MB)" : "De geselecteerde afbeelding is te groot (max 1MB)",
    "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Deze kaart is corrupt en weer hersteld. Controleer de gegevens en start het opslaan ervan om de wijzigingen permanent te maken.",
    "No contacts in here" : "Hier geen contactpersonen gevonden",
    "Name" : "Naam",
    "Organization" : "Organisatie",
    "Title" : "Titel",
    "Add field …" : "Veld toevoegen ...",
    "Save changes" : "Wijzigingen bewaren",
    "Address book" : "Adresboek",
    "Loading contacts …" : "Contacten laden ...",
    "Import into" : "Importeer in",
    "Importing..." : "Importeren...",
    "Select your addressbook" : "Selecteer je adresboek",
    "Import is disabled because no writable address book had been found." : "Import is uitgeschakeld omdat er geen beschrijfbaar adresboek is gevonden.",
    "No search result for {query}" : "Geen zoekresultaten voor {query}",
    "All contacts" : "Alle contactpersonen",
    "Post office box" : "Postbus",
    "Postal code" : "Postcode",
    "City" : "Stad",
    "State or province" : "Staat of provincie",
    "Country" : "Land",
    "Address" : "Adres",
    "(new group)" : "(nieuwe groep)",
    "Last name" : "Achternaam",
    "First name" : "Voornaam",
    "Additional names" : "Extra namen",
    "Prefix" : "Voorvoegsel",
    "Suffix" : "Achtervoegsel",
    "Importing into" : "Importeren in",
    "New contact" : "Nieuwe contactpersoon",
    "Not grouped" : "Niet gegroepeerd",
    "Sort by" : "Sorteer op",
    "There is no address book available to create a contact." : "Er is geen adresboek aanwezig om contactpersonen in op te slaan.",
    "{addressbook} shared by {owner}" : "{addressbook} gedeeld door {owner}",
    "Contact not found." : "Contact niet gevonden.",
    "You don't have permission to write to this addressbook." : "Je hebt geen rechten om wijzigen aan te brengen op dit adresboek.",
    "Contact could not be created." : "Contact kon niet worden aangemaakt.",
    "No contacts in file. Only vCard files are allowed." : "Geen contacten in bestand. Alleen VCard bestanden zijn toegestaan.",
    "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Alleen VCard versie 4.0 (RFC6350) of versie 3.0 (RFC2426) worden ondersteund.",
    "Contact could not be moved." : "Contactpersoon kon niet verplaatst worden.",
    "Contact could not be saved." : "Contact kon niet worden opgeslagen.",
    "Waiting for the server to be ready…" : "Wachten tot de server gereed is...",
    "Importing…" : "Importeren...",
    "Display name" : "Weergavenaam",
    "Nickname" : "Roepnaam",
    "Detailed name" : "Gedetailleerde naam",
    "Notes" : "Notities",
    "Website" : "Website",
    "Federated Cloud ID" : "Gefedereerde Cloud ID",
    "Home" : "Thuis",
    "Work" : "Werk",
    "Other" : "Overig",
    "Groups" : "Groepen",
    "Birthday" : "Verjaardag",
    "Anniversary" : "Jubileum",
    "Date of death" : "Sterfdatum",
    "Email" : "Email",
    "Instant messaging" : "Instant messaging",
    "Phone" : "Telefoon",
    "Mobile" : "Mobiel",
    "Work mobile" : "Werk mobiel",
    "Fax" : "Fax",
    "Fax home" : "Fax thuis",
    "Fax work" : "Fax werk",
    "Pager" : "Pieper",
    "Voice" : "Stem",
    "Car" : "Auto",
    "Work pager" : "Werk pieper",
    "Social network" : "Social network",
    "Relationship" : "Relatie",
    "Spouse" : "Echtgenoot",
    "Child" : "kind",
    "Mother" : "Moeder",
    "Father" : "Vader",
    "Parent" : "Ouder",
    "Brother" : "Broer",
    "Sister" : "Zus",
    "Relative" : "Familielid",
    "Friend" : "Vriend",
    "Colleague" : "Collega",
    "Manager" : "Manager",
    "Assistant" : "Assistent",
    "Gender" : "Geslacht",
    "Female" : "Vrouw",
    "Male" : "Man",
    "Details" : "Details",
    "Settings" : "Instellingen"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-contacts-2.1.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/nl.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contactpersonen",
    "Download" : "Downloaden",
    "Copy link" : "Link kopiëren",
    "Click to copy the link to your clipboard" : "Klik om de link naar je klembord te kopiëren",
    "Toggle sharing" : "Gedeelde omschakelen",
    "Delete" : "Verwijderen",
    "Rename" : "Hernoemen",
    "Share with users or groups" : "Delen met gebruikers of groepen",
    "can edit" : "kan bewerken",
    "Close" : "Sluiten",
    "Enabled" : "Ingeschakeld",
    "Disabled" : "Uitgeschakeld",
    "Copied!" : "Gekopieerd!",
    "Not supported!" : "Niet ondersteund!",
    "Press ⌘-C to copy." : "Druk op ⌘-C om te kopiëren.",
    "Press Ctrl-C to copy." : "Druk op Ctrl-C om te kopiëren.",
    "Address book name" : "Adresboek naam",
    "Only these special characters are allowed: -_.!?#|()" : "Alleen de volgende speciale tekens zijn toegestaan: - _ . ! ? # | ( )",
    "Address book could not be created." : "Adresboek kon niet gemaakt worden",
    "Upload new image" : "Nieuwe afbeelding uploaden",
    "The selected image is too big (max 1MB)" : "De geselecteerde afbeelding is te groot (max 1MB)",
    "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Deze kaart is corrupt en weer hersteld. Controleer de gegevens en start het opslaan ervan om de wijzigingen permanent te maken.",
    "No contacts in here" : "Hier geen contactpersonen gevonden",
    "Name" : "Naam",
    "Organization" : "Organisatie",
    "Title" : "Titel",
    "Add field …" : "Veld toevoegen ...",
    "Save changes" : "Wijzigingen bewaren",
    "Address book" : "Adresboek",
    "Loading contacts …" : "Contacten laden ...",
    "Import into" : "Importeer in",
    "Importing..." : "Importeren...",
    "Select your addressbook" : "Selecteer je adresboek",
    "Import is disabled because no writable address book had been found." : "Import is uitgeschakeld omdat er geen beschrijfbaar adresboek is gevonden.",
    "No search result for {query}" : "Geen zoekresultaten voor {query}",
    "All contacts" : "Alle contactpersonen",
    "Post office box" : "Postbus",
    "Postal code" : "Postcode",
    "City" : "Stad",
    "State or province" : "Staat of provincie",
    "Country" : "Land",
    "Address" : "Adres",
    "(new group)" : "(nieuwe groep)",
    "Last name" : "Achternaam",
    "First name" : "Voornaam",
    "Additional names" : "Extra namen",
    "Prefix" : "Voorvoegsel",
    "Suffix" : "Achtervoegsel",
    "Importing into" : "Importeren in",
    "New contact" : "Nieuwe contactpersoon",
    "Not grouped" : "Niet gegroepeerd",
    "Sort by" : "Sorteer op",
    "There is no address book available to create a contact." : "Er is geen adresboek aanwezig om contactpersonen in op te slaan.",
    "{addressbook} shared by {owner}" : "{addressbook} gedeeld door {owner}",
    "Contact not found." : "Contact niet gevonden.",
    "You don't have permission to write to this addressbook." : "Je hebt geen rechten om wijzigen aan te brengen op dit adresboek.",
    "Contact could not be created." : "Contact kon niet worden aangemaakt.",
    "No contacts in file. Only vCard files are allowed." : "Geen contacten in bestand. Alleen VCard bestanden zijn toegestaan.",
    "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Alleen VCard versie 4.0 (RFC6350) of versie 3.0 (RFC2426) worden ondersteund.",
    "Contact could not be moved." : "Contactpersoon kon niet verplaatst worden.",
    "Contact could not be saved." : "Contact kon niet worden opgeslagen.",
    "Waiting for the server to be ready…" : "Wachten tot de server gereed is...",
    "Importing…" : "Importeren...",
    "Display name" : "Weergavenaam",
    "Nickname" : "Roepnaam",
    "Detailed name" : "Gedetailleerde naam",
    "Notes" : "Notities",
    "Website" : "Website",
    "Federated Cloud ID" : "Gefedereerde Cloud ID",
    "Home" : "Thuis",
    "Work" : "Werk",
    "Other" : "Overig",
    "Groups" : "Groepen",
    "Birthday" : "Verjaardag",
    "Anniversary" : "Jubileum",
    "Date of death" : "Sterfdatum",
    "Email" : "Email",
    "Instant messaging" : "Instant messaging",
    "Phone" : "Telefoon",
    "Mobile" : "Mobiel",
    "Work mobile" : "Werk mobiel",
    "Fax" : "Fax",
    "Fax home" : "Fax thuis",
    "Fax work" : "Fax werk",
    "Pager" : "Pieper",
    "Voice" : "Stem",
    "Car" : "Auto",
    "Work pager" : "Werk pieper",
    "Social network" : "Social network",
    "Relationship" : "Relatie",
    "Specify a relationship between you and the entity represented by this vCard." : "Specificeer een relatie tussen jou en de entiteit in deze vCard.",
    "Spouse" : "Echtgenoot",
    "Child" : "kind",
    "Mother" : "Moeder",
    "Father" : "Vader",
    "Parent" : "Ouder",
    "Brother" : "Broer",
    "Sister" : "Zus",
    "Relative" : "Familielid",
    "Friend" : "Vriend",
    "Colleague" : "Collega",
    "Manager" : "Manager",
    "Assistant" : "Assistent",
    "Related" : "Gerelateerd",
    "Specify a relationship between another entity and the entity represented by this vCard." : "Specificeer een relatie tussen de entiteit in deze vCard en een andere entiteit.",
    "Contact" : "Contactpersonen",
    "Agent" : "Agent",
    "Emergency" : "Nood",
    "Co-worker" : "Medewerker",
    "Gender" : "Geslacht",
    "Female" : "Vrouw",
    "Male" : "Man",
    "Details" : "Details",
    "Settings" : "Instellingen"
},
"nplurals=2; plural=(n != 1);");
